//
//  AdMobViewController.m
//  BannersTest
//
//  Created by shalom.b on 3/29/18.
//  Copyright © 2018 shalom.bAppnext. All rights reserved.
//

#import "AdMobViewController.h"
@import GoogleMobileAds;
#import <AppnextAdMobAdapter/AppnextAdMobAdapter.h>
#import <AppnextLib/AppnextLib.h>

@interface AdMobViewController ()<GADBannerViewDelegate>
@property(nonatomic, strong) GADBannerView *bannerView;
@end

@implementation AdMobViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self loadRandomBanner];
}
- (IBAction)back:(id)sender {
     [self dismissViewControllerAnimated:YES completion:nil];
}

- (IBAction)loadBanner:(id)sender {
    [self loadBanner];
}
- (IBAction)loadLargeBanner:(id)sender {
    [self loadLargeBanner];
}
- (IBAction)loadMediumRectangle:(id)sender {
    [self loadMediumRectangleBanner];
}

- (void)loadRandomBanner {
    int r = arc4random_uniform(3);
    switch (r) {
        case 0:
            [self loadBanner];
            break;
        case 1:
            [self loadLargeBanner];
            break;
        case 2:
            [self loadMediumRectangleBanner];
            break;
        default:
            [self loadBanner];
            break;
    }
}
- (void) loadBanner{
    if(self.bannerView){
        [self.bannerView removeFromSuperview];
    }
    
    self.bannerView = [[GADBannerView alloc]
                           initWithAdSize:kGADAdSizeBanner];
    self.bannerView.adUnitID = @"ENTER_YOUR_AD_UNIT";
    self.bannerView.rootViewController = self;
    self.bannerView.delegate = self;
    [self addBannerViewToView:self.bannerView];
    
    
    BannerRequest * bannerRequest = [[BannerRequest alloc] init];
    bannerRequest.bannerType = Banner;
    GADRequest *request = [GADRequest request];
    GADCustomEventExtras *extras = [[GADCustomEventExtras alloc] init];
    NSDictionary *bannerDict = @{kAppnextBannerRequestExtraKey: bannerRequest};
    [extras setExtras:bannerDict forLabel:@"ENTER_YOUR_LABEL"];
    [request registerAdNetworkExtras:extras];
    [self.bannerView loadRequest:request];
}

- (void) loadLargeBanner{
    if(self.bannerView){
        [self.bannerView removeFromSuperview];
    }
    
    self.bannerView = [[GADBannerView alloc]
                       initWithAdSize:kGADAdSizeLargeBanner];
    self.bannerView.adUnitID = @"ENTER_YOUR_AD_UNIT";
    self.bannerView.rootViewController = self;
    self.bannerView.delegate = self;
    [self addBannerViewToView:self.bannerView];
    
    
    BannerRequest * bannerRequest = [[BannerRequest alloc] init];
    bannerRequest.bannerType = LargeBanner;
    GADRequest *request = [GADRequest request];
    GADCustomEventExtras *extras = [[GADCustomEventExtras alloc] init];
    NSDictionary *bannerDict = @{kAppnextBannerRequestExtraKey: bannerRequest};
    [extras setExtras:bannerDict forLabel:@"ENTER_YOUR_LABEL"];
    [request registerAdNetworkExtras:extras];
    [self.bannerView loadRequest:request];
}

- (void) loadMediumRectangleBanner{
    if(self.bannerView){
        [self.bannerView removeFromSuperview];
    }
    
    self.bannerView = [[GADBannerView alloc]
                       initWithAdSize:kGADAdSizeMediumRectangle];
    self.bannerView.adUnitID = @"ENTER_YOUR_AD_UNIT";
    self.bannerView.rootViewController = self;
    self.bannerView.delegate = self;
    [self addBannerViewToView:self.bannerView];
    
    
    BannerRequest * bannerRequest = [[BannerRequest alloc] init];
    bannerRequest.bannerType = MediumRectangle;
    GADRequest *request = [GADRequest request];
    GADCustomEventExtras *extras = [[GADCustomEventExtras alloc] init];
    NSDictionary *bannerDict = @{kAppnextBannerRequestExtraKey: bannerRequest};
    [extras setExtras:bannerDict forLabel:@"ENTER_YOUR_LABEL"];
    [request registerAdNetworkExtras:extras];
    [self.bannerView loadRequest:request];
}


- (void)addBannerViewToView:(UIView *)bannerView {
    bannerView.translatesAutoresizingMaskIntoConstraints = NO;
    [self.view addSubview:bannerView];
    [self.view addConstraints:@[
                                [NSLayoutConstraint constraintWithItem:bannerView
                                                             attribute:NSLayoutAttributeBottom
                                                             relatedBy:NSLayoutRelationEqual
                                                                toItem:self.view
                                                             attribute:NSLayoutAttributeBottom
                                                            multiplier:1
                                                              constant:0],
                                [NSLayoutConstraint constraintWithItem:bannerView
                                                             attribute:NSLayoutAttributeCenterX
                                                             relatedBy:NSLayoutRelationEqual
                                                                toItem:self.view
                                                             attribute:NSLayoutAttributeCenterX
                                                            multiplier:1
                                                              constant:0]
                                ]];
}

#pragma delegate
- (void)adViewDidReceiveAd:(GADBannerView *)adView {
    NSLog(@"adViewDidReceiveAd");
}

/// Tells the delegate an ad request failed.
- (void)adView:(GADBannerView *)adView
didFailToReceiveAdWithError:(GADRequestError *)error {
    NSLog(@"adView:didFailToReceiveAdWithError: %@", [error localizedDescription]);
}

/// Tells the delegate that a full-screen view will be presented in response
/// to the user clicking on an ad.
- (void)adViewWillPresentScreen:(GADBannerView *)adView {
    NSLog(@"adViewWillPresentScreen");
}

/// Tells the delegate that the full-screen view will be dismissed.
- (void)adViewWillDismissScreen:(GADBannerView *)adView {
    NSLog(@"adViewWillDismissScreen");
}

/// Tells the delegate that the full-screen view has been dismissed.
- (void)adViewDidDismissScreen:(GADBannerView *)adView {
    NSLog(@"adViewDidDismissScreen");
}

/// Tells the delegate that a user click will open another app (such as
/// the App Store), backgrounding the current app.
- (void)adViewWillLeaveApplication:(GADBannerView *)adView {
    NSLog(@"adViewWillLeaveApplication");
}

@end
